CStringArray

Struct CStringArray 

#[repr(C)]
pub struct CStringArray { pub data: *const *const c_char, pub size: usize, }
A #[repr(C)] mirror of Vec<String> with impls of CReprOf, CDrop and AsRust.

Layout is a (data, size) pair where data is a pointer to a heap-allocated array of *const c_char, each pointing to its own nul-terminated C string allocated by the Rust side. The whole structure is freed via CDrop / Drop.

Strings containing interior NUL bytes cannot be represented and will cause CReprOf::c_repr_of to fail with CReprOfError::StringContainsNullBit.

Example

use ffi_convert::{AsRust, CReprOf};
use ffi_convert_extra_ctypes::CStringArray;

let pizza_names = vec![
    "Diavola".to_string(),
    "Margarita".to_string(),
    "Regina".to_string(),
];
let c_pizza_names = CStringArray::c_repr_of(pizza_names.clone()).unwrap();
assert_eq!(c_pizza_names.size, 3);

// Deep-copy back into owned Rust strings.
let round_tripped: Vec<String> = c_pizza_names.as_rust().unwrap();
assert_eq!(round_tripped, pizza_names);

Fields

data: *const *const c_char

Pointer to the first *const c_char element of the array.

size: usize

Number of elements in the array.